from splent_io.splent_feature_profile.repositories import UserProfileRepository
from splent_framework.services.BaseService import BaseService


class UserProfileService(BaseService):
    def __init__(self):
        super().__init__(UserProfileRepository())

    def update_profile(self, user_profile_id, form):
        if form.validate():
            updated_instance = self.update(user_profile_id, **form.data)
            return updated_instance, None

        return None, form.errors



from splent_framework.seeders.BaseSeeder import BaseSeeder


class ProfileSeeder(BaseSeeder):

    def run(self):

        data = [
            # Create any Model object you want to make seed
        ]

        self.seed(data)



from flask_wtf import FlaskForm
from wtforms import StringField, SubmitField
from wtforms.validators import DataRequired, Length


class UserProfileForm(FlaskForm):
    name = StringField("Name", validators=[DataRequired(), Length(max=100)])
    surname = StringField(
        "Surname", validators=[DataRequired(), Length(max=100)]
    )
    submit = SubmitField("Save profile")



from splent_io.splent_feature_profile.models import UserProfile
from splent_framework.repositories.BaseRepository import BaseRepository


class UserProfileRepository(BaseRepository):
    def __init__(self):
        super().__init__(UserProfile)



from splent_framework.blueprints.base_blueprint import BaseBlueprint

profile_bp = BaseBlueprint("profile", __name__, template_folder="templates")


def init_feature(app):
    pass


def inject_context_vars(app):
    return {}



"""Alembic migration environment for splent_feature_profile."""

from splent_io.splent_feature_profile import models  # registers UserProfile with db.metadata  # noqa
from splent_framework.migrations.feature_env import run_feature_migrations

FEATURE_NAME = "splent_feature_profile"
FEATURE_TABLES = {"user_profile"}

run_feature_migrations(FEATURE_NAME, FEATURE_TABLES)



import pytest

from splent_framework.db import db
from splent_io.splent_feature_auth.models import User
from splent_io.splent_feature_profile.models import UserProfile
from splent_framework.helpers.test_helpers_auth import login, logout


@pytest.fixture(scope="function")
def test_client(test_client):
    """
    Extends the test_client fixture to add additional specific data for module testing.
    for module testing (por example, new users)
    """
    with test_client.application.app_context():
        user_test = User(email="user@example.com", password="test1234")
        db.session.add(user_test)
        db.session.commit()

        profile = UserProfile(
            user_id=user_test.id, name="Name", surname="Surname"
        )
        db.session.add(profile)
        db.session.commit()

    yield test_client


def test_edit_profile_page_get(test_client):
    """
    Tests access to the profile editing page via a GET request.
    """
    login_response = login(test_client, "user@example.com", "test1234")
    assert login_response.status_code == 200, "Login was unsuccessful."

    response = test_client.get("/profile/edit")
    assert (
        response.status_code == 200
    ), "The profile editing page could not be accessed."
    assert (
        b"Edit profile" in response.data
    ), "The expected content is not present on the page"

    logout(test_client)



from flask import render_template, redirect, url_for, request
from flask_login import login_required

from splent_io.splent_feature_profile import profile_bp
from splent_io.splent_feature_auth.services import AuthenticationService
from splent_io.splent_feature_profile.forms import UserProfileForm
from splent_io.splent_feature_profile.services import UserProfileService


@profile_bp.route("/profile/edit", methods=["GET", "POST"])
@login_required
def edit_profile():
    auth_service = AuthenticationService()
    profile = auth_service.get_authenticated_user_profile()
    if not profile:
        return redirect(url_for("public.index"))

    form = UserProfileForm()
    if request.method == "POST":
        service = UserProfileService()
        result, errors = service.update_profile(profile.id, form)
        return service.handle_service_response(
            result,
            errors,
            "profile.edit_profile",
            "Profile updated successfully",
            "profile/edit.html",
            form,
        )

    return render_template("profile/edit.html", form=form, profile=profile)



"""splent_feature_profile

Revision ID: 29f0c82ca134
Revises: 
Create Date: 2026-03-21 18:47:37.323348

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '29f0c82ca134'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('user_profile',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('user_id', sa.Integer(), nullable=False),
    sa.Column('name', sa.String(length=100), nullable=False),
    sa.Column('surname', sa.String(length=100), nullable=False),
    sa.ForeignKeyConstraint(['user_id'], ['user.id'], ),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('user_id')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('user_profile')
    # ### end Alembic commands ###



from splent_framework.db import db


class UserProfile(db.Model):

    id = db.Column(db.Integer, primary_key=True)
    user_id = db.Column(
        db.Integer, db.ForeignKey("user.id"), unique=True, nullable=False
    )

    name = db.Column(db.String(100), nullable=False)
    surname = db.Column(db.String(100), nullable=False)
